addons - core

#

API Docs for: 0.0.2
Show: Inherited Protected Private Deprecated

# addons Module

Defined in: `addons/webapp/OfflineModule.js:4`

The base module for the Core JS framework. It provides helper methods for implementing OOP methodologies and basic utilities such as browser detection.

This module provides the following classes:

- core.addons.CoreLocation
- core.addons.CoreWindow
- core.addons.uiscroll.CoreParallax
- core.addons.uiscroll.CoreSnap
- core.addons.webapp.LocalStorage
- core.EventBroadcaster
- core.EventDispatcher
- core.Module
- core.wirings.OfflineModule
- core.XHR